==> haskell-js-flot-0.8.3-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-flot
version: 0.8.3
id: js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
key: js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
license: MIT
copyright: Neil Mitchell 2014
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-flot#readme
synopsis: Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
abi: 682f148b16a4228534fb18ce1bf6b5c5
exposed: True
exposed-modules:
    Language.Javascript.Flot
hidden-modules: Paths_js_flot
import-dirs: /usr/lib/ghc-8.4.3/site-local/js-flot-0.8.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-flot
hs-libraries: HSjs-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html: /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-flot-0.8.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-flot
version: 0.8.3
id: js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
key: js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
license: MIT
copyright: Neil Mitchell 2014
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-flot#readme
synopsis: Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
abi: c2597aabd5a6d7df52cb7a6c31d2b86b
exposed: True
exposed-modules:
    Language.Javascript.Flot
hidden-modules: Paths_js_flot
import-dirs: /usr/lib/ghc-8.6.1/site-local/js-flot-0.8.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-flot
hs-libraries: HSjs-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html: /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
